# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class Format(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'api_name': 'str',
        'description': 'str',
        'extension': 'str',
        'default_encoding': 'str',
        'importable': 'bool',
        'exportable': 'bool',
        'default_file': 'str',
        'renders_default_locale': 'bool',
        'includes_locale_information': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'api_name': 'api_name',
        'description': 'description',
        'extension': 'extension',
        'default_encoding': 'default_encoding',
        'importable': 'importable',
        'exportable': 'exportable',
        'default_file': 'default_file',
        'renders_default_locale': 'renders_default_locale',
        'includes_locale_information': 'includes_locale_information'
    }

    def __init__(self, name=None, api_name=None, description=None, extension=None, default_encoding=None, importable=None, exportable=None, default_file=None, renders_default_locale=None, includes_locale_information=None, local_vars_configuration=None):  # noqa: E501
        """Format - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._api_name = None
        self._description = None
        self._extension = None
        self._default_encoding = None
        self._importable = None
        self._exportable = None
        self._default_file = None
        self._renders_default_locale = None
        self._includes_locale_information = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if api_name is not None:
            self.api_name = api_name
        if description is not None:
            self.description = description
        if extension is not None:
            self.extension = extension
        if default_encoding is not None:
            self.default_encoding = default_encoding
        if importable is not None:
            self.importable = importable
        if exportable is not None:
            self.exportable = exportable
        if default_file is not None:
            self.default_file = default_file
        if renders_default_locale is not None:
            self.renders_default_locale = renders_default_locale
        if includes_locale_information is not None:
            self.includes_locale_information = includes_locale_information

    @property
    def name(self):
        """Gets the name of this Format.  # noqa: E501


        :return: The name of this Format.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Format.


        :param name: The name of this Format.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def api_name(self):
        """Gets the api_name of this Format.  # noqa: E501


        :return: The api_name of this Format.  # noqa: E501
        :rtype: str
        """
        return self._api_name

    @api_name.setter
    def api_name(self, api_name):
        """Sets the api_name of this Format.


        :param api_name: The api_name of this Format.  # noqa: E501
        :type: str
        """

        self._api_name = api_name

    @property
    def description(self):
        """Gets the description of this Format.  # noqa: E501


        :return: The description of this Format.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Format.


        :param description: The description of this Format.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def extension(self):
        """Gets the extension of this Format.  # noqa: E501


        :return: The extension of this Format.  # noqa: E501
        :rtype: str
        """
        return self._extension

    @extension.setter
    def extension(self, extension):
        """Sets the extension of this Format.


        :param extension: The extension of this Format.  # noqa: E501
        :type: str
        """

        self._extension = extension

    @property
    def default_encoding(self):
        """Gets the default_encoding of this Format.  # noqa: E501


        :return: The default_encoding of this Format.  # noqa: E501
        :rtype: str
        """
        return self._default_encoding

    @default_encoding.setter
    def default_encoding(self, default_encoding):
        """Sets the default_encoding of this Format.


        :param default_encoding: The default_encoding of this Format.  # noqa: E501
        :type: str
        """

        self._default_encoding = default_encoding

    @property
    def importable(self):
        """Gets the importable of this Format.  # noqa: E501


        :return: The importable of this Format.  # noqa: E501
        :rtype: bool
        """
        return self._importable

    @importable.setter
    def importable(self, importable):
        """Sets the importable of this Format.


        :param importable: The importable of this Format.  # noqa: E501
        :type: bool
        """

        self._importable = importable

    @property
    def exportable(self):
        """Gets the exportable of this Format.  # noqa: E501


        :return: The exportable of this Format.  # noqa: E501
        :rtype: bool
        """
        return self._exportable

    @exportable.setter
    def exportable(self, exportable):
        """Sets the exportable of this Format.


        :param exportable: The exportable of this Format.  # noqa: E501
        :type: bool
        """

        self._exportable = exportable

    @property
    def default_file(self):
        """Gets the default_file of this Format.  # noqa: E501


        :return: The default_file of this Format.  # noqa: E501
        :rtype: str
        """
        return self._default_file

    @default_file.setter
    def default_file(self, default_file):
        """Sets the default_file of this Format.


        :param default_file: The default_file of this Format.  # noqa: E501
        :type: str
        """

        self._default_file = default_file

    @property
    def renders_default_locale(self):
        """Gets the renders_default_locale of this Format.  # noqa: E501


        :return: The renders_default_locale of this Format.  # noqa: E501
        :rtype: bool
        """
        return self._renders_default_locale

    @renders_default_locale.setter
    def renders_default_locale(self, renders_default_locale):
        """Sets the renders_default_locale of this Format.


        :param renders_default_locale: The renders_default_locale of this Format.  # noqa: E501
        :type: bool
        """

        self._renders_default_locale = renders_default_locale

    @property
    def includes_locale_information(self):
        """Gets the includes_locale_information of this Format.  # noqa: E501


        :return: The includes_locale_information of this Format.  # noqa: E501
        :rtype: bool
        """
        return self._includes_locale_information

    @includes_locale_information.setter
    def includes_locale_information(self, includes_locale_information):
        """Sets the includes_locale_information of this Format.


        :param includes_locale_information: The includes_locale_information of this Format.  # noqa: E501
        :type: bool
        """

        self._includes_locale_information = includes_locale_information

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Format):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Format):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.screenshots_api import ScreenshotsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestScreenshotsApi(unittest.TestCase):
    """ScreenshotsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.screenshots_api.ScreenshotsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_screenshot_create(self):
        """Test case for screenshot_create

        Create a screenshot  # noqa: E501
        """
        pass

    def test_screenshot_delete(self):
        """Test case for screenshot_delete

        Delete a screenshot  # noqa: E501
        """
        pass

    def test_screenshot_show(self):
        """Test case for screenshot_show

        Get a single screenshot  # noqa: E501
        """
        pass

    def test_screenshot_update(self):
        """Test case for screenshot_update

        Update a screenshot  # noqa: E501
        """
        pass

    def test_screenshots_list(self):
        """Test case for screenshots_list

        List screenshots  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.translation_key_details import TranslationKeyDetails  # noqa: E501
from phrase_api.rest import ApiException

class TestTranslationKeyDetails(unittest.TestCase):
    """TranslationKeyDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TranslationKeyDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.translation_key_details.TranslationKeyDetails()  # noqa: E501
        if include_optional :
            return TranslationKeyDetails(
                id = '0', 
                name = '0', 
                description = '0', 
                name_hash = '0', 
                plural = True, 
                tags = [
                    '0'
                    ], 
                data_type = '0', 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                name_plural = '0', 
                comments_count = 56, 
                max_characters_allowed = 56, 
                screenshot_url = '0', 
                unformatted = True, 
                xml_space_preserve = True, 
                original_file = '0', 
                format_value_type = '0', 
                creator = phrase_api.models.user_preview.user_preview(
                    id = '0', 
                    username = '0', 
                    name = '0', 
                    gravatar_uid = '0', )
            )
        else :
            return TranslationKeyDetails(
        )

    def testTranslationKeyDetails(self):
        """Test TranslationKeyDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class AccountSearchResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'query': 'str',
        'excerpt': 'str',
        'key': 'KeyPreview',
        'locale': 'LocalePreview',
        'project': 'Project',
        'translation': 'Translation',
        'other_translations': 'list[Translation]'
    }

    attribute_map = {
        'query': 'query',
        'excerpt': 'excerpt',
        'key': 'key',
        'locale': 'locale',
        'project': 'project',
        'translation': 'translation',
        'other_translations': 'other_translations'
    }

    def __init__(self, query=None, excerpt=None, key=None, locale=None, project=None, translation=None, other_translations=None, local_vars_configuration=None):  # noqa: E501
        """AccountSearchResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._query = None
        self._excerpt = None
        self._key = None
        self._locale = None
        self._project = None
        self._translation = None
        self._other_translations = None
        self.discriminator = None

        if query is not None:
            self.query = query
        if excerpt is not None:
            self.excerpt = excerpt
        if key is not None:
            self.key = key
        if locale is not None:
            self.locale = locale
        if project is not None:
            self.project = project
        if translation is not None:
            self.translation = translation
        if other_translations is not None:
            self.other_translations = other_translations

    @property
    def query(self):
        """Gets the query of this AccountSearchResult.  # noqa: E501


        :return: The query of this AccountSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this AccountSearchResult.


        :param query: The query of this AccountSearchResult.  # noqa: E501
        :type: str
        """

        self._query = query

    @property
    def excerpt(self):
        """Gets the excerpt of this AccountSearchResult.  # noqa: E501


        :return: The excerpt of this AccountSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._excerpt

    @excerpt.setter
    def excerpt(self, excerpt):
        """Sets the excerpt of this AccountSearchResult.


        :param excerpt: The excerpt of this AccountSearchResult.  # noqa: E501
        :type: str
        """

        self._excerpt = excerpt

    @property
    def key(self):
        """Gets the key of this AccountSearchResult.  # noqa: E501


        :return: The key of this AccountSearchResult.  # noqa: E501
        :rtype: KeyPreview
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this AccountSearchResult.


        :param key: The key of this AccountSearchResult.  # noqa: E501
        :type: KeyPreview
        """

        self._key = key

    @property
    def locale(self):
        """Gets the locale of this AccountSearchResult.  # noqa: E501


        :return: The locale of this AccountSearchResult.  # noqa: E501
        :rtype: LocalePreview
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this AccountSearchResult.


        :param locale: The locale of this AccountSearchResult.  # noqa: E501
        :type: LocalePreview
        """

        self._locale = locale

    @property
    def project(self):
        """Gets the project of this AccountSearchResult.  # noqa: E501


        :return: The project of this AccountSearchResult.  # noqa: E501
        :rtype: Project
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this AccountSearchResult.


        :param project: The project of this AccountSearchResult.  # noqa: E501
        :type: Project
        """

        self._project = project

    @property
    def translation(self):
        """Gets the translation of this AccountSearchResult.  # noqa: E501


        :return: The translation of this AccountSearchResult.  # noqa: E501
        :rtype: Translation
        """
        return self._translation

    @translation.setter
    def translation(self, translation):
        """Sets the translation of this AccountSearchResult.


        :param translation: The translation of this AccountSearchResult.  # noqa: E501
        :type: Translation
        """

        self._translation = translation

    @property
    def other_translations(self):
        """Gets the other_translations of this AccountSearchResult.  # noqa: E501


        :return: The other_translations of this AccountSearchResult.  # noqa: E501
        :rtype: list[Translation]
        """
        return self._other_translations

    @other_translations.setter
    def other_translations(self, other_translations):
        """Sets the other_translations of this AccountSearchResult.


        :param other_translations: The other_translations of this AccountSearchResult.  # noqa: E501
        :type: list[Translation]
        """

        self._other_translations = other_translations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountSearchResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountSearchResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.glossaries_api import GlossariesApi  # noqa: E501
from phrase_api.rest import ApiException


class TestGlossariesApi(unittest.TestCase):
    """GlossariesApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.glossaries_api.GlossariesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_glossaries_list(self):
        """Test case for glossaries_list

        List term bases  # noqa: E501
        """
        pass

    def test_glossary_create(self):
        """Test case for glossary_create

        Create a term base  # noqa: E501
        """
        pass

    def test_glossary_delete(self):
        """Test case for glossary_delete

        Delete a term base  # noqa: E501
        """
        pass

    def test_glossary_show(self):
        """Test case for glossary_show

        Get a single term base  # noqa: E501
        """
        pass

    def test_glossary_update(self):
        """Test case for glossary_update

        Update a term base  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class TranslationsUnverifyParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'q': 'str',
        'sort': 'str',
        'order': 'str'
    }

    attribute_map = {
        'branch': 'branch',
        'q': 'q',
        'sort': 'sort',
        'order': 'order'
    }

    def __init__(self, branch=None, q=None, sort=None, order=None, local_vars_configuration=None):  # noqa: E501
        """TranslationsUnverifyParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._q = None
        self._sort = None
        self._order = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        if q is not None:
            self.q = q
        if sort is not None:
            self.sort = sort
        if order is not None:
            self.order = order

    @property
    def branch(self):
        """Gets the branch of this TranslationsUnverifyParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this TranslationsUnverifyParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this TranslationsUnverifyParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this TranslationsUnverifyParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def q(self):
        """Gets the q of this TranslationsUnverifyParameters.  # noqa: E501

        Specify a query to find translations by content (including wildcards).<br><br> The following qualifiers are supported in the query:<br> <ul>   <li><code>id:translation_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>tags:XYZ</code> for tags on the translation</li>   <li><code>unverified:{true|false}</code> for verification status</li>   <li><code>excluded:{true|false}</code> for exclusion status</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>.   # noqa: E501

        :return: The q of this TranslationsUnverifyParameters.  # noqa: E501
        :rtype: str
        """
        return self._q

    @q.setter
    def q(self, q):
        """Sets the q of this TranslationsUnverifyParameters.

        Specify a query to find translations by content (including wildcards).<br><br> The following qualifiers are supported in the query:<br> <ul>   <li><code>id:translation_id,...</code> for queries on a comma-separated list of ids</li>   <li><code>tags:XYZ</code> for tags on the translation</li>   <li><code>unverified:{true|false}</code> for verification status</li>   <li><code>excluded:{true|false}</code> for exclusion status</li>   <li><code>updated_at:{>=|<=}2013-02-21T00:00:00Z</code> for date range queries</li> </ul> Find more examples <a href=\"#overview--usage-examples\">here</a>.   # noqa: E501

        :param q: The q of this TranslationsUnverifyParameters.  # noqa: E501
        :type: str
        """

        self._q = q

    @property
    def sort(self):
        """Gets the sort of this TranslationsUnverifyParameters.  # noqa: E501

        Sort criteria. Can be one of: key_name, created_at, updated_at.  # noqa: E501

        :return: The sort of this TranslationsUnverifyParameters.  # noqa: E501
        :rtype: str
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this TranslationsUnverifyParameters.

        Sort criteria. Can be one of: key_name, created_at, updated_at.  # noqa: E501

        :param sort: The sort of this TranslationsUnverifyParameters.  # noqa: E501
        :type: str
        """

        self._sort = sort

    @property
    def order(self):
        """Gets the order of this TranslationsUnverifyParameters.  # noqa: E501

        Order direction. Can be one of: asc, desc.  # noqa: E501

        :return: The order of this TranslationsUnverifyParameters.  # noqa: E501
        :rtype: str
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this TranslationsUnverifyParameters.

        Order direction. Can be one of: asc, desc.  # noqa: E501

        :param order: The order of this TranslationsUnverifyParameters.  # noqa: E501
        :type: str
        """

        self._order = order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranslationsUnverifyParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TranslationsUnverifyParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.translation_update_parameters import TranslationUpdateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestTranslationUpdateParameters(unittest.TestCase):
    """TranslationUpdateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TranslationUpdateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.translation_update_parameters.TranslationUpdateParameters()  # noqa: E501
        if include_optional :
            return TranslationUpdateParameters(
                branch = 'my-feature-branch', 
                content = 'My translation', 
                plural_suffix = '0', 
                unverified = True, 
                excluded = True, 
                autotranslate = True
            )
        else :
            return TranslationUpdateParameters(
        )

    def testTranslationUpdateParameters(self):
        """Test TranslationUpdateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phrase_api.api_client import ApiClient
from phrase_api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class WebhooksApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def webhook_create(self, project_id, webhook_create_parameters, **kwargs):  # noqa: E501
        """Create a webhook  # noqa: E501

        Create a new webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_create(project_id, webhook_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param WebhookCreateParameters webhook_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.webhook_create_with_http_info(project_id, webhook_create_parameters, **kwargs)  # noqa: E501

    def webhook_create_with_http_info(self, project_id, webhook_create_parameters, **kwargs):  # noqa: E501
        """Create a webhook  # noqa: E501

        Create a new webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_create_with_http_info(project_id, webhook_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param WebhookCreateParameters webhook_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Webhook, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'webhook_create_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method webhook_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `webhook_create`")  # noqa: E501
        # verify the required parameter 'webhook_create_parameters' is set
        if self.api_client.client_side_validation and ('webhook_create_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['webhook_create_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `webhook_create_parameters` when calling `webhook_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'webhook_create_parameters' in local_var_params:
            body_params = local_var_params['webhook_create_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/webhooks', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Webhook',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def webhook_delete(self, project_id, id, **kwargs):  # noqa: E501
        """Delete a webhook  # noqa: E501

        Delete an existing webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_delete(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.webhook_delete_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def webhook_delete_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Delete a webhook  # noqa: E501

        Delete an existing webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_delete_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method webhook_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `webhook_delete`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `webhook_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/webhooks/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def webhook_show(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single webhook  # noqa: E501

        Get details on a single webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_show(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.webhook_show_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def webhook_show_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single webhook  # noqa: E501

        Get details on a single webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_show_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Webhook, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method webhook_show" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `webhook_show`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `webhook_show`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/webhooks/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Webhook',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def webhook_test(self, project_id, id, **kwargs):  # noqa: E501
        """Test a webhook  # noqa: E501

        Perform a test request for a webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_test(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.webhook_test_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def webhook_test_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Test a webhook  # noqa: E501

        Perform a test request for a webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_test_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method webhook_test" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `webhook_test`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `webhook_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/webhooks/{id}/test', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def webhook_update(self, project_id, id, webhook_update_parameters, **kwargs):  # noqa: E501
        """Update a webhook  # noqa: E501

        Update an existing webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_update(project_id, id, webhook_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param WebhookUpdateParameters webhook_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.webhook_update_with_http_info(project_id, id, webhook_update_parameters, **kwargs)  # noqa: E501

    def webhook_update_with_http_info(self, project_id, id, webhook_update_parameters, **kwargs):  # noqa: E501
        """Update a webhook  # noqa: E501

        Update an existing webhook.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhook_update_with_http_info(project_id, id, webhook_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param WebhookUpdateParameters webhook_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Webhook, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'webhook_update_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method webhook_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `webhook_update`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `webhook_update`")  # noqa: E501
        # verify the required parameter 'webhook_update_parameters' is set
        if self.api_client.client_side_validation and ('webhook_update_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['webhook_update_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `webhook_update_parameters` when calling `webhook_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'webhook_update_parameters' in local_var_params:
            body_params = local_var_params['webhook_update_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/webhooks/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Webhook',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def webhooks_list(self, project_id, **kwargs):  # noqa: E501
        """List webhooks  # noqa: E501

        List all webhooks for the given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhooks_list(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Webhook]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.webhooks_list_with_http_info(project_id, **kwargs)  # noqa: E501

    def webhooks_list_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List webhooks  # noqa: E501

        List all webhooks for the given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.webhooks_list_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Webhook], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'x_phrase_app_otp',
            'page',
            'per_page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method webhooks_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `webhooks_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/webhooks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Webhook]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.blacklisted_keys_api import BlacklistedKeysApi  # noqa: E501
from phrase_api.rest import ApiException


class TestBlacklistedKeysApi(unittest.TestCase):
    """BlacklistedKeysApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.blacklisted_keys_api.BlacklistedKeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_blacklisted_key_create(self):
        """Test case for blacklisted_key_create

        Create a blocked key  # noqa: E501
        """
        pass

    def test_blacklisted_key_delete(self):
        """Test case for blacklisted_key_delete

        Delete a blocked key  # noqa: E501
        """
        pass

    def test_blacklisted_key_show(self):
        """Test case for blacklisted_key_show

        Get a single blocked key  # noqa: E501
        """
        pass

    def test_blacklisted_key_update(self):
        """Test case for blacklisted_key_update

        Update a blocked key  # noqa: E501
        """
        pass

    def test_blacklisted_keys_list(self):
        """Test case for blacklisted_keys_list

        List blocked keys  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class TagWithStats1Statistics(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'keys_total_count': 'int',
        'translations_completed_count': 'int',
        'translations_unverified_count': 'int',
        'keys_untranslated_count': 'int'
    }

    attribute_map = {
        'keys_total_count': 'keys_total_count',
        'translations_completed_count': 'translations_completed_count',
        'translations_unverified_count': 'translations_unverified_count',
        'keys_untranslated_count': 'keys_untranslated_count'
    }

    def __init__(self, keys_total_count=None, translations_completed_count=None, translations_unverified_count=None, keys_untranslated_count=None, local_vars_configuration=None):  # noqa: E501
        """TagWithStats1Statistics - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._keys_total_count = None
        self._translations_completed_count = None
        self._translations_unverified_count = None
        self._keys_untranslated_count = None
        self.discriminator = None

        if keys_total_count is not None:
            self.keys_total_count = keys_total_count
        if translations_completed_count is not None:
            self.translations_completed_count = translations_completed_count
        if translations_unverified_count is not None:
            self.translations_unverified_count = translations_unverified_count
        if keys_untranslated_count is not None:
            self.keys_untranslated_count = keys_untranslated_count

    @property
    def keys_total_count(self):
        """Gets the keys_total_count of this TagWithStats1Statistics.  # noqa: E501


        :return: The keys_total_count of this TagWithStats1Statistics.  # noqa: E501
        :rtype: int
        """
        return self._keys_total_count

    @keys_total_count.setter
    def keys_total_count(self, keys_total_count):
        """Sets the keys_total_count of this TagWithStats1Statistics.


        :param keys_total_count: The keys_total_count of this TagWithStats1Statistics.  # noqa: E501
        :type: int
        """

        self._keys_total_count = keys_total_count

    @property
    def translations_completed_count(self):
        """Gets the translations_completed_count of this TagWithStats1Statistics.  # noqa: E501


        :return: The translations_completed_count of this TagWithStats1Statistics.  # noqa: E501
        :rtype: int
        """
        return self._translations_completed_count

    @translations_completed_count.setter
    def translations_completed_count(self, translations_completed_count):
        """Sets the translations_completed_count of this TagWithStats1Statistics.


        :param translations_completed_count: The translations_completed_count of this TagWithStats1Statistics.  # noqa: E501
        :type: int
        """

        self._translations_completed_count = translations_completed_count

    @property
    def translations_unverified_count(self):
        """Gets the translations_unverified_count of this TagWithStats1Statistics.  # noqa: E501


        :return: The translations_unverified_count of this TagWithStats1Statistics.  # noqa: E501
        :rtype: int
        """
        return self._translations_unverified_count

    @translations_unverified_count.setter
    def translations_unverified_count(self, translations_unverified_count):
        """Sets the translations_unverified_count of this TagWithStats1Statistics.


        :param translations_unverified_count: The translations_unverified_count of this TagWithStats1Statistics.  # noqa: E501
        :type: int
        """

        self._translations_unverified_count = translations_unverified_count

    @property
    def keys_untranslated_count(self):
        """Gets the keys_untranslated_count of this TagWithStats1Statistics.  # noqa: E501


        :return: The keys_untranslated_count of this TagWithStats1Statistics.  # noqa: E501
        :rtype: int
        """
        return self._keys_untranslated_count

    @keys_untranslated_count.setter
    def keys_untranslated_count(self, keys_untranslated_count):
        """Sets the keys_untranslated_count of this TagWithStats1Statistics.


        :param keys_untranslated_count: The keys_untranslated_count of this TagWithStats1Statistics.  # noqa: E501
        :type: int
        """

        self._keys_untranslated_count = keys_untranslated_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagWithStats1Statistics):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TagWithStats1Statistics):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class TranslationVersionWithUser(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'content': 'str',
        'plural_suffix': 'str',
        'key': 'KeyPreview',
        'locale': 'LocalePreview',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'changed_at': 'datetime',
        'user': 'UserPreview'
    }

    attribute_map = {
        'id': 'id',
        'content': 'content',
        'plural_suffix': 'plural_suffix',
        'key': 'key',
        'locale': 'locale',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'changed_at': 'changed_at',
        'user': 'user'
    }

    def __init__(self, id=None, content=None, plural_suffix=None, key=None, locale=None, created_at=None, updated_at=None, changed_at=None, user=None, local_vars_configuration=None):  # noqa: E501
        """TranslationVersionWithUser - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._content = None
        self._plural_suffix = None
        self._key = None
        self._locale = None
        self._created_at = None
        self._updated_at = None
        self._changed_at = None
        self._user = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if content is not None:
            self.content = content
        if plural_suffix is not None:
            self.plural_suffix = plural_suffix
        if key is not None:
            self.key = key
        if locale is not None:
            self.locale = locale
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if changed_at is not None:
            self.changed_at = changed_at
        if user is not None:
            self.user = user

    @property
    def id(self):
        """Gets the id of this TranslationVersionWithUser.  # noqa: E501


        :return: The id of this TranslationVersionWithUser.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TranslationVersionWithUser.


        :param id: The id of this TranslationVersionWithUser.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def content(self):
        """Gets the content of this TranslationVersionWithUser.  # noqa: E501


        :return: The content of this TranslationVersionWithUser.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this TranslationVersionWithUser.


        :param content: The content of this TranslationVersionWithUser.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def plural_suffix(self):
        """Gets the plural_suffix of this TranslationVersionWithUser.  # noqa: E501


        :return: The plural_suffix of this TranslationVersionWithUser.  # noqa: E501
        :rtype: str
        """
        return self._plural_suffix

    @plural_suffix.setter
    def plural_suffix(self, plural_suffix):
        """Sets the plural_suffix of this TranslationVersionWithUser.


        :param plural_suffix: The plural_suffix of this TranslationVersionWithUser.  # noqa: E501
        :type: str
        """

        self._plural_suffix = plural_suffix

    @property
    def key(self):
        """Gets the key of this TranslationVersionWithUser.  # noqa: E501


        :return: The key of this TranslationVersionWithUser.  # noqa: E501
        :rtype: KeyPreview
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this TranslationVersionWithUser.


        :param key: The key of this TranslationVersionWithUser.  # noqa: E501
        :type: KeyPreview
        """

        self._key = key

    @property
    def locale(self):
        """Gets the locale of this TranslationVersionWithUser.  # noqa: E501


        :return: The locale of this TranslationVersionWithUser.  # noqa: E501
        :rtype: LocalePreview
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this TranslationVersionWithUser.


        :param locale: The locale of this TranslationVersionWithUser.  # noqa: E501
        :type: LocalePreview
        """

        self._locale = locale

    @property
    def created_at(self):
        """Gets the created_at of this TranslationVersionWithUser.  # noqa: E501


        :return: The created_at of this TranslationVersionWithUser.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this TranslationVersionWithUser.


        :param created_at: The created_at of this TranslationVersionWithUser.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this TranslationVersionWithUser.  # noqa: E501


        :return: The updated_at of this TranslationVersionWithUser.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this TranslationVersionWithUser.


        :param updated_at: The updated_at of this TranslationVersionWithUser.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def changed_at(self):
        """Gets the changed_at of this TranslationVersionWithUser.  # noqa: E501


        :return: The changed_at of this TranslationVersionWithUser.  # noqa: E501
        :rtype: datetime
        """
        return self._changed_at

    @changed_at.setter
    def changed_at(self, changed_at):
        """Sets the changed_at of this TranslationVersionWithUser.


        :param changed_at: The changed_at of this TranslationVersionWithUser.  # noqa: E501
        :type: datetime
        """

        self._changed_at = changed_at

    @property
    def user(self):
        """Gets the user of this TranslationVersionWithUser.  # noqa: E501


        :return: The user of this TranslationVersionWithUser.  # noqa: E501
        :rtype: UserPreview
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this TranslationVersionWithUser.


        :param user: The user of this TranslationVersionWithUser.  # noqa: E501
        :type: UserPreview
        """

        self._user = user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranslationVersionWithUser):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TranslationVersionWithUser):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class JobComment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'message': 'str',
        'job_id': 'str',
        'user': 'UserPreview',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'mentioned_users': 'list[UserPreview]'
    }

    attribute_map = {
        'id': 'id',
        'message': 'message',
        'job_id': 'job_id',
        'user': 'user',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'mentioned_users': 'mentioned_users'
    }

    def __init__(self, id=None, message=None, job_id=None, user=None, created_at=None, updated_at=None, mentioned_users=None, local_vars_configuration=None):  # noqa: E501
        """JobComment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._message = None
        self._job_id = None
        self._user = None
        self._created_at = None
        self._updated_at = None
        self._mentioned_users = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if message is not None:
            self.message = message
        if job_id is not None:
            self.job_id = job_id
        if user is not None:
            self.user = user
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if mentioned_users is not None:
            self.mentioned_users = mentioned_users

    @property
    def id(self):
        """Gets the id of this JobComment.  # noqa: E501


        :return: The id of this JobComment.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobComment.


        :param id: The id of this JobComment.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def message(self):
        """Gets the message of this JobComment.  # noqa: E501


        :return: The message of this JobComment.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this JobComment.


        :param message: The message of this JobComment.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def job_id(self):
        """Gets the job_id of this JobComment.  # noqa: E501


        :return: The job_id of this JobComment.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this JobComment.


        :param job_id: The job_id of this JobComment.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def user(self):
        """Gets the user of this JobComment.  # noqa: E501


        :return: The user of this JobComment.  # noqa: E501
        :rtype: UserPreview
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this JobComment.


        :param user: The user of this JobComment.  # noqa: E501
        :type: UserPreview
        """

        self._user = user

    @property
    def created_at(self):
        """Gets the created_at of this JobComment.  # noqa: E501


        :return: The created_at of this JobComment.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this JobComment.


        :param created_at: The created_at of this JobComment.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this JobComment.  # noqa: E501


        :return: The updated_at of this JobComment.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this JobComment.


        :param updated_at: The updated_at of this JobComment.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def mentioned_users(self):
        """Gets the mentioned_users of this JobComment.  # noqa: E501


        :return: The mentioned_users of this JobComment.  # noqa: E501
        :rtype: list[UserPreview]
        """
        return self._mentioned_users

    @mentioned_users.setter
    def mentioned_users(self, mentioned_users):
        """Sets the mentioned_users of this JobComment.


        :param mentioned_users: The mentioned_users of this JobComment.  # noqa: E501
        :type: list[UserPreview]
        """

        self._mentioned_users = mentioned_users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobComment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobComment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.tag_with_stats1_statistics1 import TagWithStats1Statistics1  # noqa: E501
from phrase_api.rest import ApiException

class TestTagWithStats1Statistics1(unittest.TestCase):
    """TagWithStats1Statistics1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TagWithStats1Statistics1
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.tag_with_stats1_statistics1.TagWithStats1Statistics1()  # noqa: E501
        if include_optional :
            return TagWithStats1Statistics1(
                locale = {"id":"abcd1234cdef1234abcd1234cdef1234","name":"English","code":"en-GB"}, 
                statistics = phrase_api.models.tag_with_stats_1_statistics.tag_with_stats_1_statistics(
                    keys_total_count = 56, 
                    translations_completed_count = 56, 
                    translations_unverified_count = 56, 
                    keys_untranslated_count = 56, )
            )
        else :
            return TagWithStats1Statistics1(
        )

    def testTagWithStats1Statistics1(self):
        """Test TagWithStats1Statistics1"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phrase_api.api_client import ApiClient
from phrase_api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MembersApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def member_delete(self, account_id, id, **kwargs):  # noqa: E501
        """Remove a user from the account  # noqa: E501

        Remove a user from the account. The user will be removed from the account but not deleted from Phrase. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.member_delete(account_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.member_delete_with_http_info(account_id, id, **kwargs)  # noqa: E501

    def member_delete_with_http_info(self, account_id, id, **kwargs):  # noqa: E501
        """Remove a user from the account  # noqa: E501

        Remove a user from the account. The user will be removed from the account but not deleted from Phrase. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.member_delete_with_http_info(account_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'account_id',
            'id',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method member_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'account_id' is set
        if self.api_client.client_side_validation and ('account_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['account_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `account_id` when calling `member_delete`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `member_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'account_id' in local_var_params:
            path_params['account_id'] = local_var_params['account_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/accounts/{account_id}/members/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def member_show(self, account_id, id, **kwargs):  # noqa: E501
        """Get single member  # noqa: E501

        Get details on a single user in the account. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.member_show(account_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Member
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.member_show_with_http_info(account_id, id, **kwargs)  # noqa: E501

    def member_show_with_http_info(self, account_id, id, **kwargs):  # noqa: E501
        """Get single member  # noqa: E501

        Get details on a single user in the account. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.member_show_with_http_info(account_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Member, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'account_id',
            'id',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method member_show" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'account_id' is set
        if self.api_client.client_side_validation and ('account_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['account_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `account_id` when calling `member_show`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `member_show`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'account_id' in local_var_params:
            path_params['account_id'] = local_var_params['account_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/accounts/{account_id}/members/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Member',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def member_update(self, account_id, id, member_update_parameters, **kwargs):  # noqa: E501
        """Update a member  # noqa: E501

        Update user permissions in the account. Developers and translators need <code>project_ids</code> and <code>locale_ids</code> assigned to access them. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.member_update(account_id, id, member_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str id: ID (required)
        :param MemberUpdateParameters member_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Member
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.member_update_with_http_info(account_id, id, member_update_parameters, **kwargs)  # noqa: E501

    def member_update_with_http_info(self, account_id, id, member_update_parameters, **kwargs):  # noqa: E501
        """Update a member  # noqa: E501

        Update user permissions in the account. Developers and translators need <code>project_ids</code> and <code>locale_ids</code> assigned to access them. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.member_update_with_http_info(account_id, id, member_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str id: ID (required)
        :param MemberUpdateParameters member_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Member, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'account_id',
            'id',
            'member_update_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method member_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'account_id' is set
        if self.api_client.client_side_validation and ('account_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['account_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `account_id` when calling `member_update`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `member_update`")  # noqa: E501
        # verify the required parameter 'member_update_parameters' is set
        if self.api_client.client_side_validation and ('member_update_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['member_update_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `member_update_parameters` when calling `member_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'account_id' in local_var_params:
            path_params['account_id'] = local_var_params['account_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'member_update_parameters' in local_var_params:
            body_params = local_var_params['member_update_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/accounts/{account_id}/members/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Member',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def member_update_settings(self, project_id, id, member_update_settings_parameters, **kwargs):  # noqa: E501
        """Update a member's project settings  # noqa: E501

        Update user settings in the project. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.member_update_settings(project_id, id, member_update_settings_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param MemberUpdateSettingsParameters member_update_settings_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MemberProjectDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.member_update_settings_with_http_info(project_id, id, member_update_settings_parameters, **kwargs)  # noqa: E501

    def member_update_settings_with_http_info(self, project_id, id, member_update_settings_parameters, **kwargs):  # noqa: E501
        """Update a member's project settings  # noqa: E501

        Update user settings in the project. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.member_update_settings_with_http_info(project_id, id, member_update_settings_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param MemberUpdateSettingsParameters member_update_settings_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MemberProjectDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'member_update_settings_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method member_update_settings" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `member_update_settings`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `member_update_settings`")  # noqa: E501
        # verify the required parameter 'member_update_settings_parameters' is set
        if self.api_client.client_side_validation and ('member_update_settings_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['member_update_settings_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `member_update_settings_parameters` when calling `member_update_settings`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'member_update_settings_parameters' in local_var_params:
            body_params = local_var_params['member_update_settings_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/members/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MemberProjectDetail',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def members_list(self, account_id, **kwargs):  # noqa: E501
        """List members  # noqa: E501

        Get all users active in the account. It also lists resources like projects and locales the member has access to. In case nothing is shown the default access from the role is used. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.members_list(account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Member]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.members_list_with_http_info(account_id, **kwargs)  # noqa: E501

    def members_list_with_http_info(self, account_id, **kwargs):  # noqa: E501
        """List members  # noqa: E501

        Get all users active in the account. It also lists resources like projects and locales the member has access to. In case nothing is shown the default access from the role is used. Access token scope must include <code>team.manage</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.members_list_with_http_info(account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Member], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'account_id',
            'x_phrase_app_otp',
            'page',
            'per_page'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method members_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'account_id' is set
        if self.api_client.client_side_validation and ('account_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['account_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `account_id` when calling `members_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'account_id' in local_var_params:
            path_params['account_id'] = local_var_params['account_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/accounts/{account_id}/members', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Member]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.styleguide_create_parameters import StyleguideCreateParameters  # noqa: E501
from phrase_api.rest import ApiException

class TestStyleguideCreateParameters(unittest.TestCase):
    """StyleguideCreateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StyleguideCreateParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.styleguide_create_parameters.StyleguideCreateParameters()  # noqa: E501
        if include_optional :
            return StyleguideCreateParameters(
                title = 'Web application style guide', 
                audience = 'customer-facing', 
                target_audience = 'teenager', 
                grammatical_person = 'first_person_singular', 
                vocabulary_type = 'technical', 
                business = 'We are a travel site that helps customers find the best hotels and flights.', 
                company_branding = 'ACME Inc. should never be translated.', 
                formatting = 'Never use capital letters', 
                glossary_terms = 'Apartment, cabin, loft', 
                grammar_consistency = '0', 
                literal_translation = 'Neutral', 
                overall_tone = 'Tone should be fun and light', 
                samples = 'http://www.myexample.com/my/document/path/to/samples.pdf'
            )
        else :
            return StyleguideCreateParameters(
        )

    def testStyleguideCreateParameters(self):
        """Test StyleguideCreateParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.translations_api import TranslationsApi  # noqa: E501
from phrase_api.rest import ApiException


class TestTranslationsApi(unittest.TestCase):
    """TranslationsApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.translations_api.TranslationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_translation_create(self):
        """Test case for translation_create

        Create a translation  # noqa: E501
        """
        pass

    def test_translation_exclude(self):
        """Test case for translation_exclude

        Exclude a translation from export  # noqa: E501
        """
        pass

    def test_translation_include(self):
        """Test case for translation_include

        Revoke exclusion of a translation in export  # noqa: E501
        """
        pass

    def test_translation_review(self):
        """Test case for translation_review

        Review a translation  # noqa: E501
        """
        pass

    def test_translation_show(self):
        """Test case for translation_show

        Get a single translation  # noqa: E501
        """
        pass

    def test_translation_unverify(self):
        """Test case for translation_unverify

        Mark a translation as unverified  # noqa: E501
        """
        pass

    def test_translation_update(self):
        """Test case for translation_update

        Update a translation  # noqa: E501
        """
        pass

    def test_translation_verify(self):
        """Test case for translation_verify

        Verify a translation  # noqa: E501
        """
        pass

    def test_translations_by_key(self):
        """Test case for translations_by_key

        List translations by key  # noqa: E501
        """
        pass

    def test_translations_by_locale(self):
        """Test case for translations_by_locale

        List translations by locale  # noqa: E501
        """
        pass

    def test_translations_exclude_collection(self):
        """Test case for translations_exclude_collection

        Set exclude from export flag on translations selected by query  # noqa: E501
        """
        pass

    def test_translations_include_collection(self):
        """Test case for translations_include_collection

        Remove exlude from import flag from translations selected by query  # noqa: E501
        """
        pass

    def test_translations_list(self):
        """Test case for translations_list

        List all translations  # noqa: E501
        """
        pass

    def test_translations_review_collection(self):
        """Test case for translations_review_collection

        Review translations selected by query  # noqa: E501
        """
        pass

    def test_translations_search(self):
        """Test case for translations_search

        Search translations  # noqa: E501
        """
        pass

    def test_translations_unverify_collection(self):
        """Test case for translations_unverify_collection

        Mark translations selected by query as unverified  # noqa: E501
        """
        pass

    def test_translations_verify_collection(self):
        """Test case for translations_verify_collection

        Verify translations selected by query  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class LocaleUpdateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'name': 'str',
        'code': 'str',
        'default': 'bool',
        'main': 'bool',
        'rtl': 'bool',
        'source_locale_id': 'str',
        'fallback_locale_id': 'str',
        'unverify_new_translations': 'bool',
        'unverify_updated_translations': 'bool',
        'autotranslate': 'bool'
    }

    attribute_map = {
        'branch': 'branch',
        'name': 'name',
        'code': 'code',
        'default': 'default',
        'main': 'main',
        'rtl': 'rtl',
        'source_locale_id': 'source_locale_id',
        'fallback_locale_id': 'fallback_locale_id',
        'unverify_new_translations': 'unverify_new_translations',
        'unverify_updated_translations': 'unverify_updated_translations',
        'autotranslate': 'autotranslate'
    }

    def __init__(self, branch=None, name=None, code=None, default=None, main=None, rtl=None, source_locale_id=None, fallback_locale_id=None, unverify_new_translations=None, unverify_updated_translations=None, autotranslate=None, local_vars_configuration=None):  # noqa: E501
        """LocaleUpdateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._name = None
        self._code = None
        self._default = None
        self._main = None
        self._rtl = None
        self._source_locale_id = None
        self._fallback_locale_id = None
        self._unverify_new_translations = None
        self._unverify_updated_translations = None
        self._autotranslate = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        if name is not None:
            self.name = name
        if code is not None:
            self.code = code
        if default is not None:
            self.default = default
        if main is not None:
            self.main = main
        if rtl is not None:
            self.rtl = rtl
        if source_locale_id is not None:
            self.source_locale_id = source_locale_id
        if fallback_locale_id is not None:
            self.fallback_locale_id = fallback_locale_id
        if unverify_new_translations is not None:
            self.unverify_new_translations = unverify_new_translations
        if unverify_updated_translations is not None:
            self.unverify_updated_translations = unverify_updated_translations
        if autotranslate is not None:
            self.autotranslate = autotranslate

    @property
    def branch(self):
        """Gets the branch of this LocaleUpdateParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this LocaleUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this LocaleUpdateParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this LocaleUpdateParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def name(self):
        """Gets the name of this LocaleUpdateParameters.  # noqa: E501

        Locale name  # noqa: E501

        :return: The name of this LocaleUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LocaleUpdateParameters.

        Locale name  # noqa: E501

        :param name: The name of this LocaleUpdateParameters.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def code(self):
        """Gets the code of this LocaleUpdateParameters.  # noqa: E501

        Locale ISO code  # noqa: E501

        :return: The code of this LocaleUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this LocaleUpdateParameters.

        Locale ISO code  # noqa: E501

        :param code: The code of this LocaleUpdateParameters.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def default(self):
        """Gets the default of this LocaleUpdateParameters.  # noqa: E501

        Indicates whether locale is the default locale. If set to true, the previous default locale the project is no longer the default locale.  # noqa: E501

        :return: The default of this LocaleUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this LocaleUpdateParameters.

        Indicates whether locale is the default locale. If set to true, the previous default locale the project is no longer the default locale.  # noqa: E501

        :param default: The default of this LocaleUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def main(self):
        """Gets the main of this LocaleUpdateParameters.  # noqa: E501

        Indicates whether locale is a main locale. Main locales are part of the <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\" target=\"_blank\">Verification System</a> feature.  # noqa: E501

        :return: The main of this LocaleUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._main

    @main.setter
    def main(self, main):
        """Sets the main of this LocaleUpdateParameters.

        Indicates whether locale is a main locale. Main locales are part of the <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\" target=\"_blank\">Verification System</a> feature.  # noqa: E501

        :param main: The main of this LocaleUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._main = main

    @property
    def rtl(self):
        """Gets the rtl of this LocaleUpdateParameters.  # noqa: E501

        Indicates whether locale is a RTL (Right-to-Left) locale.  # noqa: E501

        :return: The rtl of this LocaleUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._rtl

    @rtl.setter
    def rtl(self, rtl):
        """Sets the rtl of this LocaleUpdateParameters.

        Indicates whether locale is a RTL (Right-to-Left) locale.  # noqa: E501

        :param rtl: The rtl of this LocaleUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._rtl = rtl

    @property
    def source_locale_id(self):
        """Gets the source_locale_id of this LocaleUpdateParameters.  # noqa: E501

        Source locale. Can be the name or public id of the locale. Preferred is the public id.  # noqa: E501

        :return: The source_locale_id of this LocaleUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._source_locale_id

    @source_locale_id.setter
    def source_locale_id(self, source_locale_id):
        """Sets the source_locale_id of this LocaleUpdateParameters.

        Source locale. Can be the name or public id of the locale. Preferred is the public id.  # noqa: E501

        :param source_locale_id: The source_locale_id of this LocaleUpdateParameters.  # noqa: E501
        :type: str
        """

        self._source_locale_id = source_locale_id

    @property
    def fallback_locale_id(self):
        """Gets the fallback_locale_id of this LocaleUpdateParameters.  # noqa: E501

        Fallback locale for empty translations. Can be a locale name or id.  # noqa: E501

        :return: The fallback_locale_id of this LocaleUpdateParameters.  # noqa: E501
        :rtype: str
        """
        return self._fallback_locale_id

    @fallback_locale_id.setter
    def fallback_locale_id(self, fallback_locale_id):
        """Sets the fallback_locale_id of this LocaleUpdateParameters.

        Fallback locale for empty translations. Can be a locale name or id.  # noqa: E501

        :param fallback_locale_id: The fallback_locale_id of this LocaleUpdateParameters.  # noqa: E501
        :type: str
        """

        self._fallback_locale_id = fallback_locale_id

    @property
    def unverify_new_translations(self):
        """Gets the unverify_new_translations of this LocaleUpdateParameters.  # noqa: E501

        Indicates that new translations for this locale should be marked as unverified. Part of the <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\" target=\"_blank\">Advanced Workflows</a> feature.  # noqa: E501

        :return: The unverify_new_translations of this LocaleUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._unverify_new_translations

    @unverify_new_translations.setter
    def unverify_new_translations(self, unverify_new_translations):
        """Sets the unverify_new_translations of this LocaleUpdateParameters.

        Indicates that new translations for this locale should be marked as unverified. Part of the <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\" target=\"_blank\">Advanced Workflows</a> feature.  # noqa: E501

        :param unverify_new_translations: The unverify_new_translations of this LocaleUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._unverify_new_translations = unverify_new_translations

    @property
    def unverify_updated_translations(self):
        """Gets the unverify_updated_translations of this LocaleUpdateParameters.  # noqa: E501

        Indicates that updated translations for this locale should be marked as unverified. Part of the <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\" target=\"_blank\">Advanced Workflows</a> feature.  # noqa: E501

        :return: The unverify_updated_translations of this LocaleUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._unverify_updated_translations

    @unverify_updated_translations.setter
    def unverify_updated_translations(self, unverify_updated_translations):
        """Sets the unverify_updated_translations of this LocaleUpdateParameters.

        Indicates that updated translations for this locale should be marked as unverified. Part of the <a href=\"https://support.phrase.com/hc/en-us/articles/5784094755484\" target=\"_blank\">Advanced Workflows</a> feature.  # noqa: E501

        :param unverify_updated_translations: The unverify_updated_translations of this LocaleUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._unverify_updated_translations = unverify_updated_translations

    @property
    def autotranslate(self):
        """Gets the autotranslate of this LocaleUpdateParameters.  # noqa: E501

        If set, translations for this locale will be fetched automatically, right after creation.  # noqa: E501

        :return: The autotranslate of this LocaleUpdateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._autotranslate

    @autotranslate.setter
    def autotranslate(self, autotranslate):
        """Sets the autotranslate of this LocaleUpdateParameters.

        If set, translations for this locale will be fetched automatically, right after creation.  # noqa: E501

        :param autotranslate: The autotranslate of this LocaleUpdateParameters.  # noqa: E501
        :type: bool
        """

        self._autotranslate = autotranslate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocaleUpdateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LocaleUpdateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class Authorization(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'note': 'str',
        'token_last_eight': 'str',
        'hashed_token': 'str',
        'scopes': 'list[str]',
        'expires_at': 'datetime',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'note': 'note',
        'token_last_eight': 'token_last_eight',
        'hashed_token': 'hashed_token',
        'scopes': 'scopes',
        'expires_at': 'expires_at',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, note=None, token_last_eight=None, hashed_token=None, scopes=None, expires_at=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """Authorization - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._note = None
        self._token_last_eight = None
        self._hashed_token = None
        self._scopes = None
        self._expires_at = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if note is not None:
            self.note = note
        if token_last_eight is not None:
            self.token_last_eight = token_last_eight
        if hashed_token is not None:
            self.hashed_token = hashed_token
        if scopes is not None:
            self.scopes = scopes
        if expires_at is not None:
            self.expires_at = expires_at
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this Authorization.  # noqa: E501


        :return: The id of this Authorization.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Authorization.


        :param id: The id of this Authorization.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def note(self):
        """Gets the note of this Authorization.  # noqa: E501


        :return: The note of this Authorization.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this Authorization.


        :param note: The note of this Authorization.  # noqa: E501
        :type: str
        """

        self._note = note

    @property
    def token_last_eight(self):
        """Gets the token_last_eight of this Authorization.  # noqa: E501


        :return: The token_last_eight of this Authorization.  # noqa: E501
        :rtype: str
        """
        return self._token_last_eight

    @token_last_eight.setter
    def token_last_eight(self, token_last_eight):
        """Sets the token_last_eight of this Authorization.


        :param token_last_eight: The token_last_eight of this Authorization.  # noqa: E501
        :type: str
        """

        self._token_last_eight = token_last_eight

    @property
    def hashed_token(self):
        """Gets the hashed_token of this Authorization.  # noqa: E501


        :return: The hashed_token of this Authorization.  # noqa: E501
        :rtype: str
        """
        return self._hashed_token

    @hashed_token.setter
    def hashed_token(self, hashed_token):
        """Sets the hashed_token of this Authorization.


        :param hashed_token: The hashed_token of this Authorization.  # noqa: E501
        :type: str
        """

        self._hashed_token = hashed_token

    @property
    def scopes(self):
        """Gets the scopes of this Authorization.  # noqa: E501


        :return: The scopes of this Authorization.  # noqa: E501
        :rtype: list[str]
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """Sets the scopes of this Authorization.


        :param scopes: The scopes of this Authorization.  # noqa: E501
        :type: list[str]
        """

        self._scopes = scopes

    @property
    def expires_at(self):
        """Gets the expires_at of this Authorization.  # noqa: E501


        :return: The expires_at of this Authorization.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this Authorization.


        :param expires_at: The expires_at of this Authorization.  # noqa: E501
        :type: datetime
        """

        self._expires_at = expires_at

    @property
    def created_at(self):
        """Gets the created_at of this Authorization.  # noqa: E501


        :return: The created_at of this Authorization.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Authorization.


        :param created_at: The created_at of this Authorization.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Authorization.  # noqa: E501


        :return: The updated_at of this Authorization.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Authorization.


        :param updated_at: The updated_at of this Authorization.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Authorization):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Authorization):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class TranslationOrder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'lsp': 'str',
        'amount_in_cents': 'int',
        'currency': 'str',
        'message': 'str',
        'state': 'str',
        'translation_type': 'str',
        'progress_percent': 'int',
        'source_locale': 'LocalePreview',
        'target_locales': 'list[LocalePreview]',
        'tag': 'str',
        'styleguide': 'StyleguidePreview',
        'unverify_translations_upon_delivery': 'bool',
        'quality': 'bool',
        'priority': 'bool',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'lsp': 'lsp',
        'amount_in_cents': 'amount_in_cents',
        'currency': 'currency',
        'message': 'message',
        'state': 'state',
        'translation_type': 'translation_type',
        'progress_percent': 'progress_percent',
        'source_locale': 'source_locale',
        'target_locales': 'target_locales',
        'tag': 'tag',
        'styleguide': 'styleguide',
        'unverify_translations_upon_delivery': 'unverify_translations_upon_delivery',
        'quality': 'quality',
        'priority': 'priority',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, name=None, lsp=None, amount_in_cents=None, currency=None, message=None, state=None, translation_type=None, progress_percent=None, source_locale=None, target_locales=None, tag=None, styleguide=None, unverify_translations_upon_delivery=None, quality=None, priority=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """TranslationOrder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._lsp = None
        self._amount_in_cents = None
        self._currency = None
        self._message = None
        self._state = None
        self._translation_type = None
        self._progress_percent = None
        self._source_locale = None
        self._target_locales = None
        self._tag = None
        self._styleguide = None
        self._unverify_translations_upon_delivery = None
        self._quality = None
        self._priority = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if lsp is not None:
            self.lsp = lsp
        if amount_in_cents is not None:
            self.amount_in_cents = amount_in_cents
        if currency is not None:
            self.currency = currency
        if message is not None:
            self.message = message
        if state is not None:
            self.state = state
        if translation_type is not None:
            self.translation_type = translation_type
        if progress_percent is not None:
            self.progress_percent = progress_percent
        if source_locale is not None:
            self.source_locale = source_locale
        if target_locales is not None:
            self.target_locales = target_locales
        if tag is not None:
            self.tag = tag
        if styleguide is not None:
            self.styleguide = styleguide
        if unverify_translations_upon_delivery is not None:
            self.unverify_translations_upon_delivery = unverify_translations_upon_delivery
        if quality is not None:
            self.quality = quality
        if priority is not None:
            self.priority = priority
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this TranslationOrder.  # noqa: E501


        :return: The id of this TranslationOrder.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TranslationOrder.


        :param id: The id of this TranslationOrder.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this TranslationOrder.  # noqa: E501


        :return: The name of this TranslationOrder.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TranslationOrder.


        :param name: The name of this TranslationOrder.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def lsp(self):
        """Gets the lsp of this TranslationOrder.  # noqa: E501


        :return: The lsp of this TranslationOrder.  # noqa: E501
        :rtype: str
        """
        return self._lsp

    @lsp.setter
    def lsp(self, lsp):
        """Sets the lsp of this TranslationOrder.


        :param lsp: The lsp of this TranslationOrder.  # noqa: E501
        :type: str
        """

        self._lsp = lsp

    @property
    def amount_in_cents(self):
        """Gets the amount_in_cents of this TranslationOrder.  # noqa: E501


        :return: The amount_in_cents of this TranslationOrder.  # noqa: E501
        :rtype: int
        """
        return self._amount_in_cents

    @amount_in_cents.setter
    def amount_in_cents(self, amount_in_cents):
        """Sets the amount_in_cents of this TranslationOrder.


        :param amount_in_cents: The amount_in_cents of this TranslationOrder.  # noqa: E501
        :type: int
        """

        self._amount_in_cents = amount_in_cents

    @property
    def currency(self):
        """Gets the currency of this TranslationOrder.  # noqa: E501


        :return: The currency of this TranslationOrder.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this TranslationOrder.


        :param currency: The currency of this TranslationOrder.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def message(self):
        """Gets the message of this TranslationOrder.  # noqa: E501


        :return: The message of this TranslationOrder.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this TranslationOrder.


        :param message: The message of this TranslationOrder.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def state(self):
        """Gets the state of this TranslationOrder.  # noqa: E501


        :return: The state of this TranslationOrder.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this TranslationOrder.


        :param state: The state of this TranslationOrder.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def translation_type(self):
        """Gets the translation_type of this TranslationOrder.  # noqa: E501


        :return: The translation_type of this TranslationOrder.  # noqa: E501
        :rtype: str
        """
        return self._translation_type

    @translation_type.setter
    def translation_type(self, translation_type):
        """Sets the translation_type of this TranslationOrder.


        :param translation_type: The translation_type of this TranslationOrder.  # noqa: E501
        :type: str
        """

        self._translation_type = translation_type

    @property
    def progress_percent(self):
        """Gets the progress_percent of this TranslationOrder.  # noqa: E501


        :return: The progress_percent of this TranslationOrder.  # noqa: E501
        :rtype: int
        """
        return self._progress_percent

    @progress_percent.setter
    def progress_percent(self, progress_percent):
        """Sets the progress_percent of this TranslationOrder.


        :param progress_percent: The progress_percent of this TranslationOrder.  # noqa: E501
        :type: int
        """

        self._progress_percent = progress_percent

    @property
    def source_locale(self):
        """Gets the source_locale of this TranslationOrder.  # noqa: E501


        :return: The source_locale of this TranslationOrder.  # noqa: E501
        :rtype: LocalePreview
        """
        return self._source_locale

    @source_locale.setter
    def source_locale(self, source_locale):
        """Sets the source_locale of this TranslationOrder.


        :param source_locale: The source_locale of this TranslationOrder.  # noqa: E501
        :type: LocalePreview
        """

        self._source_locale = source_locale

    @property
    def target_locales(self):
        """Gets the target_locales of this TranslationOrder.  # noqa: E501


        :return: The target_locales of this TranslationOrder.  # noqa: E501
        :rtype: list[LocalePreview]
        """
        return self._target_locales

    @target_locales.setter
    def target_locales(self, target_locales):
        """Sets the target_locales of this TranslationOrder.


        :param target_locales: The target_locales of this TranslationOrder.  # noqa: E501
        :type: list[LocalePreview]
        """

        self._target_locales = target_locales

    @property
    def tag(self):
        """Gets the tag of this TranslationOrder.  # noqa: E501


        :return: The tag of this TranslationOrder.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this TranslationOrder.


        :param tag: The tag of this TranslationOrder.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def styleguide(self):
        """Gets the styleguide of this TranslationOrder.  # noqa: E501


        :return: The styleguide of this TranslationOrder.  # noqa: E501
        :rtype: StyleguidePreview
        """
        return self._styleguide

    @styleguide.setter
    def styleguide(self, styleguide):
        """Sets the styleguide of this TranslationOrder.


        :param styleguide: The styleguide of this TranslationOrder.  # noqa: E501
        :type: StyleguidePreview
        """

        self._styleguide = styleguide

    @property
    def unverify_translations_upon_delivery(self):
        """Gets the unverify_translations_upon_delivery of this TranslationOrder.  # noqa: E501


        :return: The unverify_translations_upon_delivery of this TranslationOrder.  # noqa: E501
        :rtype: bool
        """
        return self._unverify_translations_upon_delivery

    @unverify_translations_upon_delivery.setter
    def unverify_translations_upon_delivery(self, unverify_translations_upon_delivery):
        """Sets the unverify_translations_upon_delivery of this TranslationOrder.


        :param unverify_translations_upon_delivery: The unverify_translations_upon_delivery of this TranslationOrder.  # noqa: E501
        :type: bool
        """

        self._unverify_translations_upon_delivery = unverify_translations_upon_delivery

    @property
    def quality(self):
        """Gets the quality of this TranslationOrder.  # noqa: E501


        :return: The quality of this TranslationOrder.  # noqa: E501
        :rtype: bool
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        """Sets the quality of this TranslationOrder.


        :param quality: The quality of this TranslationOrder.  # noqa: E501
        :type: bool
        """

        self._quality = quality

    @property
    def priority(self):
        """Gets the priority of this TranslationOrder.  # noqa: E501


        :return: The priority of this TranslationOrder.  # noqa: E501
        :rtype: bool
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this TranslationOrder.


        :param priority: The priority of this TranslationOrder.  # noqa: E501
        :type: bool
        """

        self._priority = priority

    @property
    def created_at(self):
        """Gets the created_at of this TranslationOrder.  # noqa: E501


        :return: The created_at of this TranslationOrder.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this TranslationOrder.


        :param created_at: The created_at of this TranslationOrder.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this TranslationOrder.  # noqa: E501


        :return: The updated_at of this TranslationOrder.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this TranslationOrder.


        :param updated_at: The updated_at of this TranslationOrder.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranslationOrder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TranslationOrder):
            return True

        return self.to_dict() != other.to_dict()
